@@ -51,7 +51,6 @@ package com.openexchange.html.internal;
 
 import gnu.inet.encoding.IDNAException;
 import java.io.IOException;
-import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
 import java.net.MalformedURLException;
 import java.net.URI;
@@ -65,10 +64,6 @@ import java.util.regex.Pattern;
 import net.htmlparser.jericho.Renderer;
 import net.htmlparser.jericho.Segment;
 import net.htmlparser.jericho.Source;
-import org.apache.tika.Tika;
-import org.apache.tika.exception.TikaException;
-import org.apache.tika.metadata.Metadata;
-import org.apache.tika.metadata.Property;
 import org.htmlcleaner.CleanerProperties;
 import org.htmlcleaner.HtmlCleaner;
 import org.htmlcleaner.Serializer;
@@ -89,7 +84,6 @@ import com.openexchange.proxy.ImageContentTypeRestriction;
 import com.openexchange.proxy.ProxyException;
 import com.openexchange.proxy.ProxyRegistration;
 import com.openexchange.proxy.ProxyRegistry;
-import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 
 /**
  * {@link HTMLServiceImpl}
@@ -117,9 +111,10 @@ public final class HTMLServiceImpl implements HTMLService {
      */
 
     private final Properties tidyConfiguration;
+
     private final Map<Character, String> htmlCharMap;
+
     private final Map<String, Character> htmlEntityMap;
-    private final Tika tika;
 
     /**
      * Initializes a new {@link HTMLServiceImpl}.
@@ -133,7 +128,6 @@ public final class HTMLServiceImpl implements HTMLService {
         this.tidyConfiguration = tidyConfiguration;
         this.htmlCharMap = htmlCharMap;
         this.htmlEntityMap = htmlEntityMap;
-        tika = new Tika();
     }
 
     private static final Pattern IMG_PATTERN = Pattern.compile("<img[^>]*>", Pattern.CASE_INSENSITIVE | Pattern.DOTALL);
@@ -459,42 +453,33 @@ public final class HTMLServiceImpl implements HTMLService {
     public String sanitize(final String htmlContent, final String optConfigName, final boolean dropExternalImages, final boolean[] modified) {
         try {
             final long st = DEBUG ? System.currentTimeMillis() : 0L;
-            String html = htmlContent;
-            // Perform one-shot sanitizing
-            html = replaceHexEntities(html);
+            String confName = optConfigName;
+            if (null != confName && !confName.endsWith(".properties")) {
+                confName += ".properties";
+            }
+            String html = replaceHexEntities(htmlContent);
             html = processDownlevelRevealedConditionalComments(html);
             html = dropDoubleAccents(html);
-            // CSS- and tag-wise sanitizing
+            //html = replaceHexNbsp(html);
+            final FilterJerichoHandler handler;
             {
-                // Determine the definition to use
-                final String definition;
-                {
-                    String confName = optConfigName;
-                    if (null != confName && !confName.endsWith(".properties")) {
-                        confName += ".properties";
-                    }
-                    definition = null == confName ? null : getConfiguration().getText(confName);
+                final String definition = null == confName ? null : getConfiguration().getText(confName);
+                if (null == definition) {
+                    handler = new FilterJerichoHandler(html.length());
+                } else {
+                    handler = new FilterJerichoHandler(html.length(), definition);
                 }
-                // Handle HTML content
-                final FilterJerichoHandler handler = null == definition ? new FilterJerichoHandler(html.length()) : new FilterJerichoHandler(html.length(), definition);
-                JerichoParser.parse(html, handler.setDropExternalImages(dropExternalImages));
-                if (dropExternalImages && null != modified) {
-                    modified[0] |= handler.isImageURLFound();
-                }
-                html = handler.getHTML();
             }
-            // Repetitive sanitizing until no further replacement/changes performed
-            final boolean[] sanitized = new boolean[] { true };
-            while (sanitized[0]) {
-                sanitized[0] = false;
-                // Start sanitizing round
-                html = SaneScriptTags.saneScriptTags(html, sanitized);
+            JerichoParser.parse(html, handler.setDropExternalImages(dropExternalImages));
+            if (dropExternalImages && null != modified) {
+                modified[0] |= handler.isImageURLFound();
             }
+            final String retval = handler.getHTML();
             if (DEBUG) {
                 final long dur = System.currentTimeMillis() - st;
                 LOG.debug("\tHTMLServiceImpl.sanitize() took " + dur + "msec.");
             }
-            return html;
+            return retval;
         } catch (final ParsingDeniedException e) {
             LOG.warn("HTML content will be returned un-sanitized. Reason: "+e.getMessage(), e);
             return htmlContent;
@@ -547,44 +532,17 @@ public final class HTMLServiceImpl implements HTMLService {
         // HTMLParser.parse(htmlContent, handler);
         // return handler.getText();
 
-        try {
-            String prepared = insertBlockquoteMarker(htmlContent);
-            prepared = insertSpaceMarker(prepared);
-            String text = new Renderer(new Segment(new Source(prepared), 0, prepared.length())).setMaxLineLength(9999).setIncludeHyperlinkURLs(appendHref).toString();
-            text = quoteText(text);
-            // Drop heading whitespaces
-            text = PATTERN_HEADING_WS.matcher(text).replaceAll("$1");
-            // ... but keep enforced ones
-            text = whitespaceText(text);
-            return text;
-        } catch (final StackOverflowError soe) {
-            // Unfortunately it may happen...
-            LOG.warn("Stack-overflow during processing HTML content.", soe);
-            // Retry with Tika framework
-            try {
-                return extractFrom(new UnsynchronizedByteArrayInputStream(htmlContent.getBytes("ISO-8859-1")));
-            } catch (final Exception e) {
-                LOG.error("Error during processing HTML content.", e);
-                return "";
-            }
-        }
-    }
+        // return HTML2Text.convert(htmlContent);
 
-    private String extractFrom(final InputStream inputStream) throws IOException, TikaException {  
-        try {
-            final Metadata metadata = new Metadata();
-            metadata.set(Metadata.CONTENT_ENCODING, "ISO-8859-1");
-            metadata.set(Metadata.CONTENT_TYPE, "text/html");
-            return tika.parseToString(inputStream, metadata);
-        } finally {
-            if (null != inputStream) {
-                try {
-                    inputStream.close();
-                } catch (Exception e) {
-                    // Ignore
-                }
-            }
-        }
+        String prepared = insertBlockquoteMarker(htmlContent);
+        prepared = insertSpaceMarker(prepared);
+        String text = new Renderer(new Segment(new Source(prepared), 0, prepared.length())).setMaxLineLength(9999).setIncludeHyperlinkURLs(appendHref).toString();
+        text = quoteText(text);
+        // Drop heading whitespaces
+        text = PATTERN_HEADING_WS.matcher(text).replaceAll("$1");
+        // ... but keep enforced ones
+        text = whitespaceText(text);
+        return text;
     }
 
     private static final String SPACE_MARKER = "--?space?--";
