@@ -518,11 +518,7 @@ public final class HTMLWhitelistFilter {
     }
 
     private static boolean isNonJavaScriptURL(final String val) {
-        if (null == val) {
-            return false;
-        }
-        final String lc = val.trim().toLowerCase(Locale.US);
-        return !lc.startsWith("javascript:") && !lc.startsWith("vbscript:");
+        return (null != val && !val.trim().toLowerCase(Locale.US).startsWith("javascript:"));
     }
 
     private CharSequence getEndTagHTML(final String tagName) {
