@@ -90,6 +90,8 @@ public final class CSSMatcher {
 
     private static final Pattern PATTERN_IS_PATTERN;
 
+    private static final Pattern PATTERN_STYLE_BLOCK;
+
     private static final Pattern PATTERN_COLOR_RGB;
 
     static {
@@ -169,6 +171,8 @@ public final class CSSMatcher {
 
         PATTERN_IS_PATTERN = Pattern.compile("[unNcd*t]+");
 
+        PATTERN_STYLE_BLOCK = Pattern.compile("(\\p{Print}+\\s*\\{)([^\\}]+)\\}");
+
         PATTERN_COLOR_RGB = Pattern.compile(strCOLOR_RGB_FUNC, Pattern.CASE_INSENSITIVE);
     }
 
@@ -256,9 +260,6 @@ public final class CSSMatcher {
         }
     }
 
-    private static final Pattern PATTERN_STYLE_BLOCK = Pattern.compile("((?:#|\\.|[a-zA-Z])[^{]*?\\{)([^}]+)\\}");
-    private static final Pattern CRLF = Pattern.compile("\r?\n( {2,})?");
-
     /**
      * Iterates over CSS contained in specified string argument and checks each found element/block against given style map
      *
@@ -273,10 +274,10 @@ public final class CSSMatcher {
         /*
          * Feed matcher with buffer's content and reset
          */
-        if (cssBuilder.indexOf("{") < 0) {
+        final String css = cssBuilder.toString();
+        if (css.indexOf('{') < 0) {
             return checkCSSElements(cssBuilder, styleMap, removeIfAbsent);
         }
-        final String css = CRLF.matcher(cssBuilder).replaceAll(" ");
         final StringBuilder cssElemsBuffer = new StringBuilder(css.length());
         final Matcher m = PATTERN_STYLE_BLOCK.matcher(css);
         cssBuilder.setLength(0);
@@ -290,7 +291,7 @@ public final class CSSMatcher {
             // Check block part
             cssElemsBuffer.append(m.group(2));
             modified |= checkCSSElements(cssElemsBuffer, styleMap, removeIfAbsent);
-            cssElemsBuffer.insert(0, m.group(1)).append('}').append('\n'); // Surround with block definition
+            cssElemsBuffer.insert(0, m.group(1)).append('}'); // Surround with block definition
             final String block = cssElemsBuffer.toString();
             cssElemsBuffer.setLength(0);
             // Add to main builder
@@ -302,7 +303,7 @@ public final class CSSMatcher {
         modified |= checkCSSElements(cssElemsBuffer, styleMap, removeIfAbsent);
         final String tail = cssElemsBuffer.toString();
         cssElemsBuffer.setLength(0);
-        cssBuilder.append(tail); 
+        cssBuilder.append(tail);
         return modified;
     }
 
@@ -324,10 +325,10 @@ public final class CSSMatcher {
             /*
              * Feed matcher with buffer's content and reset
              */
-            if (cssBuilder.indexOf("{") < 0) {
+            final String css = cssBuilder.toString();
+            if (css.indexOf('{') < 0) {
                 return checkCSSElements(cssBuilder, styleMap, removeIfAbsent);
             }
-            final String css = CRLF.matcher(cssBuilder).replaceAll(" ");
             final Matcher m = PATTERN_STYLE_BLOCK.matcher(css);
             final MatcherReplacer mr = new MatcherReplacer(m, css);
             cssBuilder.setLength(0);
@@ -336,7 +337,7 @@ public final class CSSMatcher {
                 tmpBuilder.setLength(0);
                 mr.appendLiteralReplacement(
                     cssBuilder,
-                    tmpBuilder.append(m.group(1)).append(cssElemsBuffer.toString()).append('}').append('\n').toString());
+                    tmpBuilder.append(m.group(1)).append(cssElemsBuffer.toString()).append('}').toString());
                 cssElemsBuffer.setLength(0);
             }
             mr.appendTail(cssBuilder);
@@ -473,5 +474,4 @@ public final class CSSMatcher {
         }
         return retval;
     }
-
 }
