@@ -572,11 +572,7 @@ public final class FilterJerichoHandler implements JerichoHandler {
     }
 
     private static boolean isNonJavaScriptURL(final String val) {
-        if (null == val) {
-            return false;
-        }
-        final String lc = val.trim().toLowerCase(Locale.US);
-        return !lc.startsWith("javascript:") && !lc.startsWith("vbscript:");
+        return (null != val && !val.trim().toLowerCase(Locale.US).startsWith("javascript:"));
     }
 
     public void handleDocDeclaration(final String docDecl) {
